summaryrefslogtreecommitdiffstats
path: root/kmobile/kmobile.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmobile/kmobile.h')
-rw-r--r--kmobile/kmobile.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/kmobile/kmobile.h b/kmobile/kmobile.h
index f9bfefb38..58d3f4c23 100644
--- a/kmobile/kmobile.h
+++ b/kmobile/kmobile.h
@@ -42,14 +42,14 @@ protected:
* This function is called when it is time for the app to save its
* properties for session management purposes.
*/
- void saveProperties(KConfig *);
+ void saveProperties(TDEConfig *);
/**
* This function is called when this app is restored. The KConfig
* object points to the session management config file that was saved
* with @ref saveProperties
*/
- void readProperties(KConfig *);
+ void readProperties(TDEConfig *);
public slots:
@@ -87,7 +87,7 @@ private:
bool queryClose();
private:
- KConfig *m_config;
+ TDEConfig *m_config;
KMobileView *m_view;
SystemTray *m_systemTray;
@@ -42,14 +42,14 @@ protected:
/**
- * This function is called when this app is restored. The KConfig
+ * This function is called when this app is restored. The TDEConfig
* object points to the session management config file that was saved
* with @ref saveProperties